[Python-checkins] cpython (3.3): Issue #20474: Fix "unexpected success" test_socket failures on OS X 10.7+.

ned.deily python-checkins at python.org
Mon Feb 3 23:02:56 CET 2014


http://hg.python.org/cpython/rev/63efacd80f8e
changeset:   88946:63efacd80f8e
branch:      3.3
parent:      88944:4f0e4a68dcdb
user:        Ned Deily <nad at acm.org>
date:        Mon Feb 03 13:58:31 2014 -0800
summary:
  Issue #20474: Fix "unexpected success" test_socket failures on OS X 10.7+.

files:
  Lib/test/test_socket.py |  8 ++++----
  Misc/NEWS               |  2 ++
  2 files changed, 6 insertions(+), 4 deletions(-)


diff --git a/Misc/NEWS b/Misc/NEWS
--- a/Misc/NEWS
+++ b/Misc/NEWS
@@ -365,6 +365,8 @@
 
 - Issue #19085: Added basic tests for all tkinter widget options.
 
+- Issue #20474: Fix test_socket "unexpected success" failures on OS X 10.7+.
+
 Documentation
 -------------
 

diff --git a/Lib/test/test_socket.py b/Lib/test/test_socket.py
--- a/Lib/test/test_socket.py
+++ b/Lib/test/test_socket.py
@@ -3490,12 +3490,12 @@
         self.assertNotIsInstance(cm.exception, socket.timeout)
         self.assertEqual(cm.exception.errno, errno.EINTR)
 
-    # Issue #12958: The following tests have problems on Mac OS X
-    @support.anticipate_failure(sys.platform == "darwin")
+    # Issue #12958: The following tests have problems on OS X prior to 10.7
+    @support.requires_mac_ver(10, 7)
     def testInterruptedSendTimeout(self):
         self.checkInterruptedSend(self.serv_conn.send, b"a"*512)
 
-    @support.anticipate_failure(sys.platform == "darwin")
+    @support.requires_mac_ver(10, 7)
     def testInterruptedSendtoTimeout(self):
         # Passing an actual address here as Python's wrapper for
         # sendto() doesn't allow passing a zero-length one; POSIX
@@ -3504,7 +3504,7 @@
         self.checkInterruptedSend(self.serv_conn.sendto, b"a"*512,
                                   self.serv_addr)
 
-    @support.anticipate_failure(sys.platform == "darwin")
+    @support.requires_mac_ver(10, 7)
     @requireAttrs(socket.socket, "sendmsg")
     def testInterruptedSendmsgTimeout(self):
         self.checkInterruptedSend(self.serv_conn.sendmsg, [b"a"*512])
-- 
Repository URL: http://hg.python.org/cpython


More information about the Python-checkins mailing list